==> App-Aphra-0.1.3.tar.gz: App-Aphra-0.1.3/README.md <==
[![Build Status](https://github.com/davorg-cpan/app-aphra/actions/workflows/perltest.yml/badge.svg?branch=master)](https://github.com/davorg-cpan/app-aphra/actions/workflows/perltest.yml) [![Coverage Status](https://coveralls.io/repos/github/davorg-cpan/app-aphra/badge.svg?branch=master)](https://coveralls.io/github/davorg-cpan/app-aphra?branch=master)

> Aphra Behn (/ˈæfrə bɛn/; 14 December 1640? – 16 April 1689) was a British
> playwright, poet, translator and fiction writer from the Restoration era. As
> one of the first English women to earn her living by her writing, she broke
> cultural barriers and served as a literary role model for later generations
> of women authors. Rising from obscurity, she came to the notice of Charles
> II, who employed her as a spy in Antwerp. Upon her return to London and a
> probable brief stay in debtors' prison, she began writing for the stage. She
> belonged to a coterie of poets and famous libertines such as John Wilmot,
> Lord Rochester. She wrote under the pastoral pseudonym Astrea. During the
> turbulent political times of the Exclusion Crisis, she wrote an epilogue
> and prologue that brought her into legal trouble; she thereafter devoted
> most of her writing to prose genres and translations. A staunch supporter
> of the Stuart line, she declined an invitation from Bishop Burnet to write
> a welcoming poem to the new king William III. She died shortly after.
> 
> She is famously remembered in Virginia Woolf's A Room of One's Own: "All
> women together ought to let flowers fall upon the tomb of Aphra Behn which
> is, most scandalously but rather appropriately, in Westminster Abbey, for
> it was she who earned them the right to speak their minds." Her grave
> is not included in the Poets' Corner but lies in the East Cloister near
> the steps to the church.
>
> *Aphra Behn* - [Wikipedia](https://en.wikipedia.org/wiki/Aphra_Behn)

==> App-Aphra-0.2.4.tar.gz: App-Aphra-0.2.4/README.md <==
[![Build Status](https://github.com/davorg-cpan/app-aphra/actions/workflows/perltest.yml/badge.svg?branch=master)](https://github.com/davorg-cpan/app-aphra/actions/workflows/perltest.yml) [![Coverage Status](https://coveralls.io/repos/github/davorg-cpan/app-aphra/badge.svg?branch=master)](https://coveralls.io/github/davorg-cpan/app-aphra?branch=master)

![Aphra Behn](https://aphra.perlhacks.com/img/aphra.webp "Aphra Behn")

> **Aphra Behn** (/ˈæfrə bɛn/; 14 December 1640? – 16 April 1689) was a British
> playwright, poet, translator and fiction writer from the Restoration era. As
> one of the first English women to earn her living by her writing, she broke
> cultural barriers and served as a literary role model for later generations
> of women authors. Rising from obscurity, she came to the notice of Charles
> II, who employed her as a spy in Antwerp. Upon her return to London and a
> probable brief stay in debtors' prison, she began writing for the stage. She
> belonged to a coterie of poets and famous libertines such as John Wilmot,
> Lord Rochester. She wrote under the pastoral pseudonym Astrea. During the
> turbulent political times of the Exclusion Crisis, she wrote an epilogue
> and prologue that brought her into legal trouble; she thereafter devoted
> most of her writing to prose genres and translations. A staunch supporter
> of the Stuart line, she declined an invitation from Bishop Burnet to write
> a welcoming poem to the new king William III. She died shortly after.
> 
> She is famously remembered in Virginia Woolf's *A Room of One's Own*: "All
> women together ought to let flowers fall upon the tomb of Aphra Behn which
> is, most scandalously but rather appropriately, in Westminster Abbey, for
> it was she who earned them the right to speak their minds." Her grave
> is not included in the Poets' Corner but lies in the East Cloister near
> the steps to the church.
>
> *Aphra Behn* - [Wikipedia](https://en.wikipedia.org/wiki/Aphra_Behn)
